@@ -1,9 +1,9 @@
 from typing import List
-from figurl.core.Figure import Figure
+from ....core.Figure import Figure
 
 class Markdown(Figure):
     def __init__(self, source: str):
         data = {
             'source': source
         }
-        super().__init__(type='Markdown.1', data=data)
\ No newline at end of file
+        super().__init__(view_url='gs://figurl/markdown-1', data=data)
\ No newline at end of file
